@@ -1,4 +1,4 @@
-`func.med.mode` <- function(functions)
+func.med.mode <- function(functions)
 {
   depth.mode(functions)$median
 }
